@@ -7,16 +7,18 @@ T = TypeVar("T")
 
 
 def topsort(
-    root: T,
     dag: Mapping[T, Iterable[T]],
 ) -> List[List[T]]:
-    """Topological sort with grouping."""
+    """A specialized toplogical sort that:
+    1. Groups dependencies so that they can be executed concurrently.
+    2. Includes disconnected components of the DAG (i.e. executes the entire DAG).
+    """
     groups: List[List[T]] = []
     dependant_count: Dict[T, int] = dict.fromkeys(dag, 0)
     for subdeps in dag.values():
         for subdep in subdeps:
             dependant_count[subdep] += 1
-    q: Deque[T] = deque([root])
+    q: Deque[T] = deque([node for node in dag.keys() if dependant_count[node] == 0])
     while q:
         group = list(q)
         q.clear()
