@@ -10,6 +10,7 @@ from typing import (
     Coroutine,
     Deque,
     Dict,
+    Iterable,
     List,
     Optional,
     Union,
@@ -30,13 +31,8 @@ from di.exceptions import (
 from di.executors import DefaultExecutor
 from di.types import FusedContextManager
 from di.types.dependencies import DependantProtocol, DependencyParameter
-from di.types.executor import AsyncExecutor, SyncExecutor
-from di.types.providers import (
-    Dependency,
-    DependencyProvider,
-    DependencyProviderType,
-    DependencyType,
-)
+from di.types.executor import AsyncExecutor, SyncExecutor, Values
+from di.types.providers import Dependency, DependencyProviderType, DependencyType
 from di.types.scopes import Scope
 from di.types.solved import SolvedDependency
 
@@ -111,13 +107,16 @@ class Container:
         return self._state.binds[provider]
 
     def solve(
-        self, dependency: DependantProtocol[DependencyType]
+        self,
+        dependency: DependantProtocol[DependencyType],
+        siblings: Optional[Iterable[DependantProtocol[Any]]] = None,
     ) -> SolvedDependency[DependencyType]:
         """Solve a dependency.
 
-        This is done automatically when calling `execute`, but you can store the returned value
-        from this function and call `execute_solved` instead if you know that your binds
-        will not be changing between calls.
+        Returns a SolvedDependency that can be executed to get the dependency's value.
+
+        The `siblings` paramter can be used to pass additional dependencies that should be executed
+        that aren't strictly needed to solve `dependency`.
         """
 
         if dependency.call in self._state.binds:
@@ -125,7 +124,7 @@ class Container:
 
         param_graph: Dict[
             DependantProtocol[Any],
-            Dict[str, DependencyParameter[DependantProtocol[Any]]],
+            List[DependencyParameter[DependantProtocol[Any]]],
         ] = {}
 
         dep_registry: Dict[DependantProtocol[Any], DependantProtocol[Any]] = {}
@@ -134,13 +133,13 @@ class Container:
 
         def get_params(
             dep: DependantProtocol[Any],
-        ) -> Dict[str, DependencyParameter[DependantProtocol[Any]]]:
+        ) -> List[DependencyParameter[DependantProtocol[Any]]]:
             params = dep.get_dependencies().copy()
-            for keyword, param in params.items():
+            for idx, param in enumerate(params):
                 assert param.dependency.call is not None
                 if param.dependency.call in self._state.binds:
-                    params[keyword] = DependencyParameter[Any](
-                        dependency=self._state.binds.get(param.dependency.call),
+                    params[idx] = DependencyParameter[Any](
+                        dependency=self._state.binds[param.dependency.call],
                         parameter=param.parameter,
                     )
             return params
@@ -168,13 +167,24 @@ class Container:
                 params = get_params(dep)
                 param_graph[dep] = params
                 dep_dag[dep] = []
-                for param in params.values():
+                for param in params:
                     subdep = param.dependency
                     dep_dag[dep].append(subdep)
                     if subdep not in dep_registry:
                         q.append(subdep)
 
-        topsorted_groups = topsort(dependency, dep_dag)
+        siblings = siblings or ()
+        for sibling in siblings:
+            solved = self.solve(sibling)
+            param_graph.update(solved.dag)
+            dep_dag.update(
+                {
+                    dep: [p.dependency for p in params]
+                    for dep, params in solved.dag.items()
+                }
+            )
+
+        topsorted_groups = topsort(dep_dag)
         tasks = self._build_tasks(topsorted_groups, param_graph)
         return SolvedDependency(dependency=dependency, dag=param_graph, _tasks=tasks)  # type: ignore
 
@@ -186,16 +196,16 @@ class Container:
         ],
         dag: Dict[
             DependantProtocol[Any],
-            Dict[str, DependencyParameter[DependantProtocol[Any]]],
+            List[DependencyParameter[DependantProtocol[Any]]],
         ],
     ) -> Union[AsyncTask[DependencyType], SyncTask[DependencyType]]:
 
-        task_dependencies: Dict[str, DependencyParameter[Task[DependencyProvider]]] = {}
-
-        for param_name, param in dag[dependency].items():
-            task_dependencies[param_name] = DependencyParameter(
+        task_dependencies: List[DependencyParameter[Task[Any]]] = [
+            DependencyParameter(
                 dependency=tasks[param.dependency], parameter=param.parameter
             )
+            for param in dag[dependency]
+        ]
 
         if is_async_gen_callable(dependency.call) or is_coroutine_callable(
             dependency.call
@@ -209,7 +219,7 @@ class Container:
         topsort: List[List[DependantProtocol[Any]]],
         dag: Dict[
             DependantProtocol[Any],
-            Dict[str, DependencyParameter[DependantProtocol[Any]]],
+            List[DependencyParameter[DependantProtocol[Any]]],
         ],
     ) -> List[List[Union[AsyncTask[Dependency], SyncTask[Dependency]]]]:
         tasks: Dict[
@@ -248,7 +258,7 @@ class Container:
 
         for dep, params in solved.dag.items():
             check_scope(dep)
-            for param in params.values():
+            for param in params:
                 subdep = param.dependency
                 check_scope(subdep)
                 check_is_inner(dep, subdep)
@@ -256,7 +266,9 @@ class Container:
     def execute_sync(
         self,
         solved: SolvedDependency[DependencyType],
+        *,
         validate_scopes: bool = True,
+        values: Optional[Values] = None,
     ) -> DependencyType:
         """Execute an already solved dependency.
 
@@ -264,6 +276,7 @@ class Container:
         and then disable scope validation in subsequent runs with `validate_scope=False`.
         """
         results: Dict[Task[Any], Any] = {}
+        values = values or {}
         with self.enter_local_scope(self._default_scope):
             if validate_scopes:
                 self._validate_scopes(solved)
@@ -280,12 +293,14 @@ class Container:
                 [functools.partial(t.compute, self._state, results) for t in group]
                 for group in tasks
             ]
-            return executor.execute_sync(stateful_tasks, lambda: results[tasks[-1][0]])  # type: ignore
+            return executor.execute_sync(stateful_tasks, lambda: results[tasks[-1][0]], values)  # type: ignore
 
     async def execute_async(
         self,
         solved: SolvedDependency[DependencyType],
+        *,
         validate_scopes: bool = True,
+        values: Optional[Values] = None,
     ) -> DependencyType:
         """Execute an already solved dependency.
 
@@ -293,6 +308,7 @@ class Container:
         and then disable scope validation in subsequent runs with `validate_scope=False`.
         """
         results: Dict[Task[Any], Any] = {}
+        values = values or {}
         async with self.enter_local_scope(self._default_scope):
             if validate_scopes:
                 self._validate_scopes(solved)
@@ -311,4 +327,4 @@ class Container:
                 [functools.partial(t.compute, self._state, results) for t in group]
                 for group in tasks
             ]
-            return await executor.execute_async(stateful_tasks, lambda: results[tasks[-1][0]])  # type: ignore
+            return await executor.execute_async(stateful_tasks, lambda: results[tasks[-1][0]], values)  # type: ignore
