@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import inspect
-from typing import Any, Dict, Optional, overload
+from typing import Any, Dict, List, Optional, overload
 
 from di._docstrings import join_docstring_from
 from di._inspect import get_parameters, infer_call_from_annotation
@@ -11,7 +11,6 @@ from di.types.providers import (
     AsyncGeneratorProvider,
     CallableProvider,
     CoroutineProvider,
-    DependencyProvider,
     DependencyProviderType,
     DependencyType,
     GeneratorProvider,
@@ -25,12 +24,17 @@ _VARIABLE_PARAMETER_KINDS = (
 
 
 class Dependant(DependantProtocol[DependencyType], object):
+    wire: bool
+    autowire: bool
+
     @overload
     def __init__(
         self,
         call: Optional[AsyncGeneratorProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
         share: bool = True,
+        wire: bool = True,
+        autowire: bool = True,
     ) -> None:
         ...
 
@@ -40,6 +44,8 @@ class Dependant(DependantProtocol[DependencyType], object):
         call: Optional[CoroutineProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
         share: bool = True,
+        wire: bool = True,
+        autowire: bool = True,
     ) -> None:
         ...
 
@@ -49,6 +55,8 @@ class Dependant(DependantProtocol[DependencyType], object):
         call: Optional[GeneratorProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
         share: bool = True,
+        wire: bool = True,
+        autowire: bool = True,
     ) -> None:
         ...
 
@@ -58,6 +66,8 @@ class Dependant(DependantProtocol[DependencyType], object):
         call: Optional[CallableProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
         share: bool = True,
+        wire: bool = True,
+        autowire: bool = True,
     ) -> None:
         ...
 
@@ -66,16 +76,20 @@ class Dependant(DependantProtocol[DependencyType], object):
         call: Optional[DependencyProviderType[DependencyType]] = None,
         scope: Scope = None,
         share: bool = True,
+        wire: bool = True,
+        autowire: bool = True,
     ) -> None:
         self.call = call
         self.scope = scope
         self.dependencies: Optional[
-            Dict[str, DependencyParameter[DependantProtocol[Any]]]
+            List[DependencyParameter[DependantProtocol[Any]]]
         ] = None
         self.share = share
+        self.autowire = autowire
+        self.wire = wire
 
     def __repr__(self) -> str:
-        share = "" if self.share is False else ", share=False"
+        share = "" if self.share is False else ", share=True"
         return f"{self.__class__.__name__}(call={self.call}, scope={self.scope}{share})"
 
     @join_docstring_from(DependantProtocol[Any].__hash__)
@@ -94,7 +108,7 @@ class Dependant(DependantProtocol[DependencyType], object):
     @join_docstring_from(DependantProtocol[Any].get_dependencies)
     def get_dependencies(
         self,
-    ) -> Dict[str, DependencyParameter[DependantProtocol[Any]]]:
+    ) -> List[DependencyParameter[DependantProtocol[Any]]]:
         """For the Dependant implementation, this serves as a cache layer on
         top of gather_dependencies.
         """
@@ -112,49 +126,38 @@ class Dependant(DependantProtocol[DependencyType], object):
 
     def register_parameter(self, param: inspect.Parameter) -> None:
         if self.call is None:
-            call = infer_call_from_annotation(param)
-            if call is inspect.Parameter.empty:
-                raise WiringError(
-                    "Cannot wire a parameter with no default and no type annotation"
-                )
-            self.call = call
+            self.call = infer_call_from_annotation(param)
 
     def gather_dependencies(
         self,
-    ) -> Dict[str, DependencyParameter[DependantProtocol[Any]]]:
+    ) -> List[DependencyParameter[DependantProtocol[Any]]]:
         """Collect this dependencies sub dependencies.
 
         The returned dict corresponds to keyword arguments that will be passed
         to this dependencies `call` after all sub-dependencies are themselves resolved.
         """
+        if self.wire is False:
+            return []
         assert (
             self.call is not None
         ), "Container should have assigned call; this is a bug!"
-        res: Dict[str, DependencyParameter[DependantProtocol[Any]]] = {}
-        for param_name, param in self.gather_parameters().items():
+        res: List[DependencyParameter[DependantProtocol[Any]]] = []
+        for param in self.gather_parameters().values():
             if param.kind in _VARIABLE_PARAMETER_KINDS:
                 raise WiringError(
                     "Dependencies may not use variable positional or keyword arguments"
                 )
             if isinstance(param.default, Dependant):
                 sub_dependant: DependantProtocol[Any] = param.default
-            elif param.default is param.empty:
-                sub_dependant = self.create_sub_dependant(
-                    call=None,
-                    scope=self.scope,
-                    share=self.share,
-                )
+            elif param.default is param.empty and self.autowire:
+                sub_dependant = self.create_sub_dependant(param)
             else:
                 continue  # pragma: no cover
             sub_dependant.register_parameter(param)
-            res[param_name] = DependencyParameter(
-                dependency=sub_dependant, parameter=param
-            )
+            res.append(DependencyParameter(dependency=sub_dependant, parameter=param))
         return res
 
-    def create_sub_dependant(
-        self, call: Optional[DependencyProvider], scope: Scope, share: bool
-    ) -> DependantProtocol[Any]:
+    def create_sub_dependant(self, param: inspect.Parameter) -> DependantProtocol[Any]:
         """Create a Dependant instance from a sub-dependency of this Dependency.
 
         This is used in the scenario where a transient dependency is inferred from a type hint.
@@ -171,4 +174,13 @@ class Dependant(DependantProtocol[DependencyType], object):
 
         It is recommended to transfer `scope` and possibly `share` to sub-dependencies created in this manner.
         """
-        return Dependant[Any](call=call, scope=scope, share=share)
+        if param.annotation is inspect.Parameter.empty:
+            raise WiringError(
+                "Cannot wire a parameter with no default and no type annotation"
+            )
+        return Dependant[Any](
+            call=param.annotation,
+            scope=self.scope,
+            share=self.share,
+            autowire=self.autowire,
+        )
