@@ -19,8 +19,10 @@ from di.types.scopes import Scope
 def Depends(
     call: Optional[AsyncGeneratorProvider[DependencyType]] = None,
     *,
-    scope: Optional[Scope] = None,
-    share: bool = True
+    scope: Scope = None,
+    share: bool = True,
+    wire: bool = True,
+    autowire: bool = True,
 ) -> DependencyType:
     ...
 
@@ -29,8 +31,10 @@ def Depends(
 def Depends(
     call: Optional[CoroutineProvider[DependencyType]] = None,
     *,
-    scope: Optional[Scope] = None,
-    share: bool = True
+    scope: Scope = None,
+    share: bool = True,
+    wire: bool = True,
+    autowire: bool = True,
 ) -> DependencyType:
     ...
 
@@ -39,8 +43,10 @@ def Depends(
 def Depends(
     call: Optional[GeneratorProvider[DependencyType]] = None,
     *,
-    scope: Optional[Scope] = None,
-    share: bool = True
+    scope: Scope = None,
+    share: bool = True,
+    wire: bool = True,
+    autowire: bool = True,
 ) -> DependencyType:
     ...
 
@@ -49,8 +55,10 @@ def Depends(
 def Depends(
     call: Optional[CallableProvider[DependencyType]] = None,
     *,
-    scope: Optional[Scope] = None,
-    share: bool = True
+    scope: Scope = None,
+    share: bool = True,
+    wire: bool = True,
+    autowire: bool = True,
 ) -> DependencyType:
     ...
 
@@ -58,7 +66,9 @@ def Depends(
 def Depends(
     call: Optional[DependencyProviderType[DependencyType]] = None,
     *,
-    scope: Optional[Scope] = None,
-    share: bool = True
+    scope: Scope = None,
+    share: bool = True,
+    wire: bool = True,
+    autowire: bool = True,
 ) -> DependencyType:
-    return Dependant(call=call, scope=scope, share=share)  # type: ignore
+    return Dependant(call=call, scope=scope, share=share, wire=wire, autowire=autowire)  # type: ignore
