@@ -1,5 +1,7 @@
 import sys
-from typing import Awaitable, Callable, List, TypeVar, Union
+from typing import Any, Awaitable, Callable, List, Mapping, TypeVar, Union
+
+from di.types.providers import DependencyProvider
 
 if sys.version_info < (3, 8):
     from typing_extensions import Protocol
@@ -7,8 +9,11 @@ else:
     from typing import Protocol
 
 ResultType = TypeVar("ResultType")
+Dependency = Any
 
-Task = Callable[[], Union[None, Awaitable[None]]]
+Values = Mapping[DependencyProvider, Dependency]
+
+Task = Callable[[Values], Union[None, Awaitable[None]]]
 
 
 class SyncExecutor(Protocol):
@@ -16,6 +21,7 @@ class SyncExecutor(Protocol):
         self,
         tasks: List[List[Task]],
         get_result: Callable[[], ResultType],
+        values: Values,
     ) -> ResultType:
         raise NotImplementedError
 
@@ -25,5 +31,6 @@ class AsyncExecutor(Protocol):
         self,
         tasks: List[List[Task]],
         get_result: Callable[[], ResultType],
+        values: Values,
     ) -> ResultType:
         raise NotImplementedError
